<?php

App::uses('AppComponent', 'Controller/Component');

class UserManagerComponent extends AppComponent {

	/**
	 * register a user
	 *
	 * @param 	object 	$Model 		The model object to use for saving
	 * @return 	array 	$result 	Two element array - result(bool) / data(array)
	 */
	public function registerUser($Model) {
		if ($Model->register($this->_controller->request->data)) {

			$activationType = Configure::read('SiteSetting.users.activation');

			if ($activationType == 'auto') {
				$message = 'Your account has been created, logging in...';

				$fullUser = $Model->getUserForLogin($Model->id);
				$this->_controller->Auth->login($fullUser);
				$redirect = $this->_controller->Auth->redirect();

			} elseif ($activationType == 'email') {
				$message = 'Your account has been created, however you will be unable to login until you have click the link in the verifcation email you have been sent.';
			} else {
				$message = 'Your account has been created but needs manually verifying by an adminitrator. You will be emailed once your account is active.';
			}

			$this->_controller->Flash->success(
				$message
			);

			if (! isset($redirect)) {
				$redirect = array(
					'action' => 'login'
				);
			}

			$result = true;
			$returnData = array(
				'redirect' => $redirect
			);

		} else {

			$validationErrors = array();
			foreach ($Model->validationErrors as $key => $errors) {
				$validationErrors[] = $errors['0'];
			}

			$errors = array(
				'description' => 'Please correct the following issues and try agan:',
				'list' => $validationErrors
			);

			$this->_controller->Flash->fail(
				$errors
			);

			$result = false;
			$returnData = array(
				'errors' => $validationErrors
			);
		}

		return array(
			'result' => $result,
			'data' => $returnData
		);
	}

}
